/**
 * Logic for using SPI to communicate between the AVR and other devices.
 */

#include <avr/io.h>

#include "include/spi.h"

/* Initialize the microcontroller's SPI interface. */
void SPI_init(void) {
    // Set MOSI, SCK, and SS as outputs
    DDRB = (1<<DDB3) | (1<<DDB5) | (1<<DDB2);

    // Enable SPI, become master, set SPI clock rate to 1 MHz.
    SPCR = (1<<SPE) | (1<<MSTR) | (1<<SPR0);
}

/* Send a byte over the SPI interface. */
void SPI_transmit(char data) {
    // Put the data in the SPI Data Register.
    SPDR = data;

    // Wait for transmission to complete.
    while(!(SPSR & (1<<SPIF)))
        ;
}

/* Receive a byte from the SPI interface. */
uint8_t SPI_receive(void) {
    // Wait for reception to complete.
    while (!(SPSR & (1<<SPIF)))
        ;

    // Return received value from data register.
    return SPDR;
}
